
# This file was generated by 'versioneer.py' (0.28) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-02-15T13:11:28+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "8134e6bebf50e4b4b428e07eebc98c3b2e851774",
 "version": "v23.04.00a230215"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
